@@ -16,6 +16,7 @@ __PACKAGE__->primary_key('recordingId');
 __PACKAGE__->params(
     userId => 'Str',
     userIP => 'Str',
+    length => 'Int',
     );
 
 has 'creationDate' => (is => 'rw', isa => 'HiResDate', required => 1,
@@ -60,6 +61,22 @@ Elive::Entity::Recording - Elluminate Recording Entity class
 
 =cut
 
+sub BUILDARGS {
+    my $class = shift;
+    my $spec = shift;
+
+    die "usage $class->new({ ... }, ...)"
+	unless Elive::Util::_reftype($spec) eq 'HASH';
+
+    my %args = %{ $spec };
+
+    if (defined $args{data}) {
+	$args{size} ||= length( $args{data} );
+    }
+
+    return \%args;
+}
+
 =head1 METHODS
 
 =cut
@@ -85,7 +102,9 @@ sub download {
 	or die "not connected";
 
     my $som = $connection->call('getRecordingStream',
-				recordingId => $recording_id,
+				%{ $self->_freeze({
+				       recordingId => $recording_id,
+				       })},
 	);
 
     my $results = $self->_get_results($som, $connection);
@@ -124,7 +143,6 @@ sub download {
                     roomName => 'Meeting of the Smiths',
                     version => Elive->server_details->version,
                     data => $binary_data,
-                    size => length($binary_data),
 	     },
          );
 
@@ -135,7 +153,9 @@ Note: the C<facilitator>, when supplied must match the facilitator for the given
 =cut
 
 sub upload {
-    my ($class, $insert_data, %opt) = @_;
+    my ($class, $spec, %opt) = @_;
+
+    my $insert_data = $class->BUILDARGS( $spec );
 
     my $binary_data = delete $insert_data->{data};
 
@@ -149,8 +169,9 @@ sub upload {
 	    or die "not connected";
 
 	my $som = $connection->call('streamRecording',
-				    recordingId => $self->recordingId,
-				    length => $size,
+				    %{ $class->_freeze({
+					   recordingId => $self->recordingId,
+					   length => $size}) },
 				    stream => (SOAP::Data
 					       ->type('hexBinary')
 					       ->value($binary_data)),
@@ -171,11 +192,12 @@ or recovering recordings that have not been closed cleanly.
     my $import_filename = sprintf("%s_recordingData.bin", $recording->recordingId);
 
     #
-    # Somehow import the file to the server. This needs to be uploaded
-    # to ${instancesRoot}/${instanceName}/WEB-INF/resources/recordings
+    # Somehow import the file to the server and work-out the byte-size.
+    # This needs to be uploaded to:
+    #        ${instancesRoot}/${instanceName}/WEB-INF/resources/recordings
     # where $instanceRoot is typically /opt/ElluminateLive/manager/tomcat
     #
-    import_recording($import_filename);
+    my $bytes = import_recording($import_filename); # implementation dependant
 
     my $recording = Elive::Entity::Recording->insert({
         recordingId => $recordingId,
@@ -184,7 +206,7 @@ or recovering recordings that have not been closed cleanly.
         meetingId => $meetingId,
         facilitator => $meeting->faciliator,
         version => Elive->server_details->version,
-        size => length($number_of_bytes),
+        size => $bytes,
    });
 
 
